==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/src/emsa1.cpp <==
/*************************************************
* EMSA1 Source File                              *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/emsa1.h>
#include <opencl/ieee1363.h>
#include <opencl/lookup.h>

namespace OpenCL {

/*************************************************
* EMSA1 Update Operation                         *
*************************************************/
void EMSA1::update(const byte input[], u32bit length)
   {
   hash->update(input, length);
   }

/*************************************************
* Return the raw (unencoded) data                *
*************************************************/
SecureVector<byte> EMSA1::raw_data()
   {
   return hash->final();
   }

/*************************************************
* EMSA1 Encode Operation                         *
*************************************************/
SecureVector<byte> EMSA1::encoding_of(const byte msg[], u32bit msg_len,
                                      u32bit output_length)
   {
   if(msg_len != hash->OUTPUT_LENGTH)
      throw Invalid_Argument("EMSA1::encoding_of: Invalid size for input");

   if(8*msg_len <= output_length)
      return SecureVector<byte>(msg, msg_len);

   u32bit shift = 8*msg_len - output_length;

   u32bit byte_shift = shift / 8, bit_shift = shift % 8;
   SecureVector<byte> digest(msg_len - byte_shift);

   for(u32bit j = 0; j != msg_len - byte_shift; j++)
      digest[j] = msg[j];

   if(bit_shift)
      {
      byte carry = 0;
      for(u32bit j = 0; j != digest.size(); j++)
         {
         byte temp = digest[j];
         digest[j] = (temp >> bit_shift) | carry;
         carry = (temp << (8 - bit_shift));
         }
      }

   return digest;
   }

/*************************************************
* EMSA1 Constructor                              *
*************************************************/
EMSA1::EMSA1(const std::string& hash_name) :
   hash(get_hash(hash_name))
   {
   }

}

==> OpenCL-0.8.6.tgz: OpenCL-0.8.6/src/emsa1.cpp <==
/*************************************************
* EMSA1 Source File                              *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#include <opencl/emsa1.h>
#include <opencl/lookup.h>

namespace OpenCL {

/*************************************************
* EMSA1 Update Operation                         *
*************************************************/
void EMSA1::update(const byte input[], u32bit length)
   {
   hash->update(input, length);
   }

/*************************************************
* Return the raw (unencoded) data                *
*************************************************/
SecureVector<byte> EMSA1::raw_data()
   {
   return hash->final();
   }

/*************************************************
* EMSA1 Encode Operation                         *
*************************************************/
SecureVector<byte> EMSA1::encoding_of(const SecureVector<byte>& msg,
                                      u32bit output_length)
   {
   if(msg.size() != hash->OUTPUT_LENGTH)
      throw Invalid_Argument("EMSA1::encoding_of: Invalid size for input");
   if(8*msg.size() <= output_length)
      return SecureVector<byte>(msg, msg.size());

   u32bit shift = 8*msg.size() - output_length;

   u32bit byte_shift = shift / 8, bit_shift = shift % 8;
   SecureVector<byte> digest(msg.size() - byte_shift);

   for(u32bit j = 0; j != msg.size() - byte_shift; j++)
      digest[j] = msg[j];

   if(bit_shift)
      {
      byte carry = 0;
      for(u32bit j = 0; j != digest.size(); j++)
         {
         byte temp = digest[j];
         digest[j] = (temp >> bit_shift) | carry;
         carry = (temp << (8 - bit_shift));
         }
      }

   return digest;
   }

/*************************************************
* EMSA1 Constructor                              *
*************************************************/
EMSA1::EMSA1(const std::string& hash_name) :
   hash(get_hash(hash_name))
   {
   }

}
